@@ -15,6 +15,9 @@ G_BEGIN_DECLS
 /* VOID:DOUBLE (gpdf-marshal.list:3) */
 #define gpdf_marshal_VOID__DOUBLE	g_cclosure_marshal_VOID__DOUBLE
 
+/* VOID:POINTER (gpdf-marshal.list:4) */
+#define gpdf_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
+
 G_END_DECLS
 
 #endif /* __gpdf_marshal_MARSHAL_H__ */
